[CMake] CMake: how to use 'if condition' in command add_custom_command(...)

2016-04-18 Thread Chaos Zhang
Hi, 

Is there a way to use Linux command 'if' like this : 
 
For i need to execute 'if condition' in make phase rather than cmake phase. 

Thanks a lot 
Chaos Zhang 



--
View this message in context: 
http://cmake.3232098.n2.nabble.com/CMake-how-to-use-if-condition-in-command-add-custom-command-tp7593278.html
Sent from the CMake mailing list archive at Nabble.com.
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


[Cmake-commits] CMake branch, master, updated. v3.5.2-468-g7d4c99a

2016-04-18 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  7d4c99a957b37e6905af3fe6ea96b7fdf2b8359c (commit)
  from  fa4ae9fb12b61473f028a3ec38433f82a030c578 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7d4c99a957b37e6905af3fe6ea96b7fdf2b8359c
commit 7d4c99a957b37e6905af3fe6ea96b7fdf2b8359c
Author: Kitware Robot <kwro...@kitware.com>
AuthorDate: Tue Apr 19 00:01:05 2016 -0400
Commit: Kitware Robot <kwro...@kitware.com>
CommitDate: Tue Apr 19 00:01:05 2016 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index af88d2c..3304213 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 5)
-set(CMake_VERSION_PATCH 20160418)
+set(CMake_VERSION_PATCH 20160419)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [CMake] Is there any ongoing work to support toolset Clang 3.7 with Microsoft CodeGen (v140_clang_3_7)

2016-04-18 Thread forumer

Hi,

I have tested a nightly build and I have noticed that when compiling in 
debug mode, debug symbols

are not generated and we cannot debug.
When I compare vcxproj files when I enable manually Full Debug 
Information from project properties it seems that

the GenerateDebugInformation is set to FullDebug.
Could you fix it ?



Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">


  Use
  Level3
  Disabled
  
_DEBUG;_CONSOLE;%(PreprocessorDefinitions)

  FullDebug


  Console
  true

...


Thanks

Le 2016-04-08 20:38, Gilles Khouzam a écrit :

Yes, support has been added to the nightly builds. Mariusz has added
support for this.

-Original Message-
From: CMake [mailto:cmake-boun...@cmake.org] On Behalf Of
foru...@smartmobili.com
Sent: Friday, April 1, 2016 03:16
To: CMake ML 
Subject: [CMake] Is there any ongoing work to support toolset Clang
3.7 with Microsoft CodeGen (v140_clang_3_7)

Hi,

Microsoft has released a new toolset using clang for the code analysis
and with VS2015 code generator.



--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[Cmake-commits] CMake branch, next, updated. v3.5.2-999-g7faf4c2

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  7faf4c230e2915fb670f395d981fa69ada9fc327 (commit)
   via  0fb503b612650266336c1bc5124c1cf6c37f8d5c (commit)
  from  c8e7c7c1e546dd208a6f454dc6f4de9d892f9e2c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7faf4c230e2915fb670f395d981fa69ada9fc327
commit 7faf4c230e2915fb670f395d981fa69ada9fc327
Merge: c8e7c7c 0fb503b
Author: Brad King 
AuthorDate: Mon Apr 18 16:14:04 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 16:14:04 2016 -0400

Merge topic 'intel-compiler-features' into next

0fb503b6 Revert topic 'intel-compiler-features'


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0fb503b612650266336c1bc5124c1cf6c37f8d5c
commit 0fb503b612650266336c1bc5124c1cf6c37f8d5c
Author: Brad King 
AuthorDate: Mon Apr 18 16:13:49 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 16:13:49 2016 -0400

Revert topic 'intel-compiler-features'

diff --git a/Help/manual/cmake-compile-features.7.rst 
b/Help/manual/cmake-compile-features.7.rst
index 366d4ec..caf5bac 100644
--- a/Help/manual/cmake-compile-features.7.rst
+++ b/Help/manual/cmake-compile-features.7.rst
@@ -309,4 +309,3 @@ versions specified for each:
 * ``GNU``: GNU compiler versions 4.4 through 5.0.
 * ``MSVC``: Microsoft Visual Studio versions 2010 through 2015.
 * ``SunPro``: Oracle SolarisStudio version 12.4.
-* ``Intel``: Intel compiler versions 12.0 through 16.0 on UNIX platforms.
diff --git a/Help/release/dev/intel-compiler-features.rst 
b/Help/release/dev/intel-compiler-features.rst
deleted file mode 100644
index f154dc9..000
--- a/Help/release/dev/intel-compiler-features.rst
+++ /dev/null
@@ -1,6 +0,0 @@
-intel-compiler-features

-
-* The :manual:`Compile Features ` functionality
-  is now aware of features supported by Intel C++ compilers versions 12.1
-  through 16.0 on UNIX platforms.
diff --git a/Modules/CMakeCCompilerId.c.in b/Modules/CMakeCCompilerId.c.in
index 95184c9..c107dfd 100644
--- a/Modules/CMakeCCompilerId.c.in
+++ b/Modules/CMakeCCompilerId.c.in
@@ -34,11 +34,7 @@ char const *info_cray = "INFO" ":" 
"compiler_wrapper[CrayPrgEnv]";
 @CMAKE_C_COMPILER_ID_ERROR_FOR_TEST@
 
 #if !defined(__STDC__)
-# if defined(_MSC_VER) && !defined(__clang__)
-#  define C_DIALECT "90"
-# else
-#  define C_DIALECT
-# endif
+# define C_DIALECT
 #elif __STDC_VERSION__ >= 201000L
 # define C_DIALECT "11"
 #elif __STDC_VERSION__ >= 199901L
diff --git a/Modules/Compiler/Intel-C-FeatureTests.cmake 
b/Modules/Compiler/Intel-C-FeatureTests.cmake
deleted file mode 100644
index bd1a290..000
--- a/Modules/Compiler/Intel-C-FeatureTests.cmake
+++ /dev/null
@@ -1,25 +0,0 @@
-# References:
-#   - 
https://software.intel.com/en-us/articles/iso-iec-standards-language-conformance-for-intel-c-compiler
-#   - https://software.intel.com/en-us/articles/c99-support-in-intel-c-compiler
-#   - https://software.intel.com/en-us/articles/c11-support-in-intel-c-compiler
-
-# FIXME: Intel C feature detection works only when simulating the GNU compiler.
-if("x${CMAKE_C_SIMULATE_ID}" STREQUAL "xMSVC")
-  return()
-endif()
-
-set(_cmake_oldestSupported "__INTEL_COMPILER >= 1110")
-
-set(DETECT_C99 "defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L")
-set(DETECT_C11 "defined(__STDC_VERSION__) && __STDC_VERSION__ >= 201000L")
-
-set(Intel_C90 "${_cmake_oldestSupported}")
-set(Intel_C99 "${_cmake_oldestSupported} && ${DETECT_C99}")
-set(Intel_C11 "__INTEL_COMPILER >= 1500 && ${DETECT_C11}")
-
-
-set(_cmake_feature_test_c_static_assert "${Intel_C11}")
-
-set(_cmake_feature_test_c_restrict "${Intel_C99}")
-set(_cmake_feature_test_c_variadic_macros "${Intel_C99}")
-set(_cmake_feature_test_c_function_prototypes "${Intel_C90}")
diff --git a/Modules/Compiler/Intel-C.cmake b/Modules/Compiler/Intel-C.cmake
index 006ba1f..77363eb 100644
--- a/Modules/Compiler/Intel-C.cmake
+++ b/Modules/Compiler/Intel-C.cmake
@@ -8,55 +8,5 @@ set(CMAKE_C_FLAGS_RELWITHDEBINFO_INIT "-O2 -g -DNDEBUG")
 
 set(CMAKE_DEPFILE_FLAGS_C "-MD -MT  -MF ")
 
-if(NOT "x${CMAKE_C_SIMULATE_ID}" STREQUAL "xMSVC")
-  if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 15.0.0)
-set(CMAKE_C11_STANDARD_COMPILE_OPTION "-std=c11")
-set(CMAKE_C11_EXTENSION_COMPILE_OPTION "-std=c11")
-  endif()
-
-  if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
-set(CMAKE_C90_STANDARD_COMPILE_OPTION "-std=c89")
-set(CMAKE_C90_EXTENSION_COMPILE_OPTION "-std=c89")
-

[Cmake-commits] CMake branch, next, updated. v3.5.2-997-gc8e7c7c

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  c8e7c7c1e546dd208a6f454dc6f4de9d892f9e2c (commit)
   via  9b9313b1af045f46791a49b5a229e99f1073f723 (commit)
   via  402f7e24896467ddc40dba60efb4d32bc963c67e (commit)
   via  ad20143a819367edc06a2dab45e5c9a223911046 (commit)
   via  8e0f17d63bcd6f00f36f7c887ca3043593aa3e4c (commit)
  from  62a4f33bb4fd75931de450d8284d647217b9df51 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c8e7c7c1e546dd208a6f454dc6f4de9d892f9e2c
commit c8e7c7c1e546dd208a6f454dc6f4de9d892f9e2c
Merge: 62a4f33 9b9313b
Author: Brad King 
AuthorDate: Mon Apr 18 15:57:07 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 15:57:07 2016 -0400

Merge topic 'intel-compiler-features' into next

9b9313b1 WCDH: Add Intel to list of supported compilers
402f7e24 Features: Record standards and features for Intel C on UNIX
ad20143a Features: Record standards and features for Intel C++ on UNIX
8e0f17d6 Features: Detect C default dialect on MSVC-like compilers


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9b9313b1af045f46791a49b5a229e99f1073f723
commit 9b9313b1af045f46791a49b5a229e99f1073f723
Author: Robert Maynard 
AuthorDate: Thu Apr 14 08:57:07 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 15:54:46 2016 -0400

WCDH: Add Intel to list of supported compilers

diff --git a/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt 
b/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt
index c538280..0fc25dc 100644
--- a/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt
+++ b/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt
@@ -11,7 +11,7 @@ get_property(c_known_features GLOBAL PROPERTY 
CMAKE_C_KNOWN_FEATURES)
 write_compiler_detection_header(
   FILE "${CMAKE_CURRENT_BINARY_DIR}/test_compiler_detection.h"
   PREFIX TEST
-  COMPILERS GNU Clang AppleClang MSVC SunPro
+  COMPILERS GNU Clang AppleClang MSVC SunPro Intel
   VERSION 3.1
   PROLOG "// something"
   EPILOG "// more"
@@ -78,6 +78,12 @@ if (CMAKE_CXX_COMPILER_ID STREQUAL "MSVC")
   endif()
 endif()
 
+if (CMAKE_CXX_COMPILER_ID STREQUAL "Intel")
+  list(APPEND false_defs EXPECTED_COMPILER_CXX_DELEGATING_CONSTRUCTORS)
+  list(APPEND false_defs EXPECTED_COMPILER_CXX_VARIADIC_TEMPLATES)
+  set(true_defs "")
+endif()
+
 if (CMAKE_C_COMPILER_ID STREQUAL "GNU"
 OR CMAKE_C_COMPILER_ID STREQUAL "Clang"
 OR CMAKE_C_COMPILER_ID STREQUAL "AppleClang")
@@ -104,7 +110,7 @@ write_compiler_detection_header(
   PREFIX MULTI
   OUTPUT_FILES_VAR multi_files
   OUTPUT_DIR 
"${CMAKE_CURRENT_BINARY_DIR}/compiler_multi_files/compiler_support"
-  COMPILERS GNU Clang AppleClang MSVC SunPro
+  COMPILERS GNU Clang AppleClang MSVC SunPro Intel
   VERSION 3.1
   FEATURES
 ${cxx_known_features} ${c_known_features}

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=402f7e24896467ddc40dba60efb4d32bc963c67e
commit 402f7e24896467ddc40dba60efb4d32bc963c67e
Author: Robert Maynard 
AuthorDate: Fri Apr 15 13:40:30 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 15:54:44 2016 -0400

Features: Record standards and features for Intel C on UNIX

Skip this for now on Windows where Intel C simulates MSVC.

diff --git a/Modules/Compiler/Intel-C-FeatureTests.cmake 
b/Modules/Compiler/Intel-C-FeatureTests.cmake
new file mode 100644
index 000..bd1a290
--- /dev/null
+++ b/Modules/Compiler/Intel-C-FeatureTests.cmake
@@ -0,0 +1,25 @@
+# References:
+#   - 

Re: [CMake] CMakeLists.txt: How to print a message if ctest fails?

2016-04-18 Thread Muhammad Osama
Hi Miroslav,

Thank you for replying! I added this in my root CMakeLists.txt, purposely
made the ctest's test fail but didn't get the output message.
Is this script suppose to be added inside CMakeLists.txt? Or am I doing
this incorrectly?

Thanks again,

On Mon, Apr 18, 2016 at 6:30 AM, Matějů Miroslav, Ing. <
mateju.miros...@azd.cz> wrote:

> Hi Muhammad,
>
> you can use a CTest script, see
> https://cmake.org/Wiki/CMake_Scripting_Of_CTest for details. I use the
> following code in my CTest script:
>
>
>
> if(configure_failed OR build_failed OR test_failed)
>
> message(FATAL_ERROR "Test ${CTEST_BUILD_NAME} failed.")
>
> endif()
>
>
>
> Best regards,
>
> Miroslav
>
>
>
> *From:* CMake [mailto:cmake-boun...@cmake.org] *On Behalf Of *Muhammad
> Osama
> *Sent:* Friday, April 15, 2016 8:53 PM
> *To:* cmake@cmake.org
> *Subject:* [CMake] CMakeLists.txt: How to print a message if ctest fails?
>
>
>
> Is there a way I can setup CMakeLists.txt to print a message if ctest
> tests fail? For example:
>
> cmake ..
> make
> ctest // fails
> message output: Please contact x...@mail.com to resolve testing problems.
>
> ​Note the message output is not for cmake but for ctest.​
>
>
>
> --​​
>
> Muhammad
>



-- 
*Muhammad*
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

Re: [cmake-developers] CMake API for warnings

2016-04-18 Thread Brad King
On 04/13/2016 01:20 AM, Ruslan Baratov wrote:
>>> new variable like CMAKE_CHECK_WARNINGS_CONFLICTS=OFF may control this.
>> I'd prefer to avoid extra knobs if possible.
> Okay, what about CMake warning for developer? (cmake -Wdev/cmake -Wno-dev)

Sure.

>>> You mean this:
>>>
>>>   compatibility-c++98=off
>>>   inline=off
>>>   special-members=off
>>>   catch-semantic-changed=off
>>>   covered-switch-default=off
>>>   inherits-via-dominance=off
>>>   name-length-exceeded=off
>>>   padded=off
>>>   this-used-in-init=off
>>>   EVERYTHING=on
>>>   EVERYTHING=error
>>>
>>> versus this one:
>>>
>>>   DISABLE
>>> compatibility-c++98
>>> inline
>>> special-members
>>> catch-semantic-changed
>>> covered-switch-default
>>> inherits-via-dominance
>>> name-length-exceeded
>>> padded
>>> this-used-in-init
>>>   ENABLE
>>> EVERYTHING
>>>   TREAT_AS_ERROR
>>> EVERYTHING
[snip]
> All I'm trying to say about ENABLE/DISABLE lists is that if user will 
> have N warnings to enable and M warnings to disable he will not write N 
> times *=on and M times *=off and probably will just create helper functions:

I realized there is a difference between the low-level plumbing representation
of this in the property values and the porcelain provided by a new command
like target_compile_warnings.  I've been thinking of the plumbing and you've
been thinking of the porcelain.  They do not have to be the same.  The
plumbing could even use 0/1 instead of off/on to work better with a genex.

We need to work out designs for both such that they can work together and
the command can easily map to the internal property representation.  Perhaps
having separate properties for _ENABLE, _DISABLE, and _ERROR is the way to
go, perhaps not.  Either way we can diagnose inconsistent value combinations.

> so how about this:
> 
> compile_warnings(DISABLE foo CONFIGURATION Debug)
> compile_warnings(ERROR foo CONFIGURATION NOT Debug)

I'd prefer to use generator expressions for the per-config values instead
of an explicit CONFIGURATION porcelain, at least at first.

> I'm pretty sure all compilers have flag to enable all kind of available 
> warnings (it may not call "All", e.g. -Weverything for Clang). Even if 
> there is such compiler we can use maximum level + adding extra warnings 
> explicitly. There must be abstracted group that allow to enable 
> everything.

Okay.  We can document the "everything" mode as meaning CMake will do
a best-effort to add all warnings the compiler can provide, at least
without resorting to adding lots of individual flags.

Thanks,
-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [CMake] Patch for BundleUtilities to ignore specified files

2016-04-18 Thread Brad King
On 04/18/2016 10:20 AM, Roman Wüger wrote:
> attached is a patch with which files can be specified which should not be 
> resolved.

Thanks.  Please include a documentation update too.

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [cmake-developers] 0016046: GHS Multi Generator: duplicate object file names

2016-04-18 Thread Brad King
On 04/17/2016 04:22 PM, Geoffrey Viola wrote:
> Attached is a patch to fix the bug tracked at 
> https://cmake.org/Bug/view.php?id=16046.
> It adds a special source property to set the obj filename for the GHS MULTI 
> generator.
> It is necessary, because GHS MULTI has a bug where it can’t compile two 
> source files
> with the same filenames.

Thanks.  However, I do not think it should be the project's responsibility
to set the OBJECT_FILE property for this.  CMake's VS IDE generator has
the same problem so we generate specific object file names automatically
when the defaults will not be unique.  See logic here:

  cmLocalVisualStudioGenerator::ComputeObjectFilenames
  
https://cmake.org/gitweb?p=cmake.git;a=blob;f=Source/cmLocalVisualStudioGenerator.cxx;hb=v3.5.2#l41

and use of AddExplicitObjectName in particular.

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] Patch for BundleUtilities to ignore specified files

2016-04-18 Thread Brad King
On 04/18/2016 10:20 AM, Roman Wüger wrote:
> attached is a patch with which files can be specified which should not be 
> resolved.

Thanks.  Please include a documentation update too.

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[CMake] How to check if Eclipse CDT4 generated project is set up correctly?

2016-04-18 Thread Nils Rathmann

Hi,
when I setup with the Eclipse CDT4 generator, as described here: 
https://cmake.org/Wiki/Eclipse_CDT4_Generator4


my [Targets] folder contains virtual folders for CMakeRules, Header 
Files, Object Files, Resources and Source Files, but only the source 
files folder is filled. The other folders are always empty, even if I 
build the target or the whole project. Is there a documentation where I 
can see how a generated Eclipse project should look like? When I compare 
my project with the sample screenshot in the wiki linked above, it looks 
totally different (mine has a lot of virtual folders like Subprojects, 
Targets, ...)


To summarize: Is there a description how a Eclipse CDT4 generated 
project should look like and how to use it best?


Details:
- OpenSUSE 13.2; Eclipse Mars  (4.5) with CDT 8.8.1.201602051005; cmake 
3.5.0
- Project created with cmake-gui as out-of-source build next to the 
source directory.


Thank you,
Nils

--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


[Cmake-commits] CMake branch, next, updated. v3.5.2-992-g62a4f33

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  62a4f33bb4fd75931de450d8284d647217b9df51 (commit)
   via  fa4ae9fb12b61473f028a3ec38433f82a030c578 (commit)
   via  ef713503c8b9b317fdbd21c75d332febd77c31a3 (commit)
  from  5734a2f6d5e26ed8d07c46e95c5a62ac73ed6384 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=62a4f33bb4fd75931de450d8284d647217b9df51
commit 62a4f33bb4fd75931de450d8284d647217b9df51
Merge: 5734a2f fa4ae9f
Author: Brad King 
AuthorDate: Mon Apr 18 11:07:19 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 11:07:19 2016 -0400

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-467-gfa4ae9f

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  fa4ae9fb12b61473f028a3ec38433f82a030c578 (commit)
   via  0f96ef00cbe8dd82cee32f61f9da43e66e42f446 (commit)
   via  563bf9dd8a207e04697a92d8bcd239f52400b355 (commit)
   via  7c36d2067b00996fcead56310f4fc4fa58434247 (commit)
   via  1f6bd8a93f602f9d4dde1c3ea697211897f25827 (commit)
   via  18b6676bff6d50ebc38c75e7998298fca75a01c5 (commit)
  from  ef713503c8b9b317fdbd21c75d332febd77c31a3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fa4ae9fb12b61473f028a3ec38433f82a030c578
commit fa4ae9fb12b61473f028a3ec38433f82a030c578
Merge: ef71350 0f96ef0
Author: Brad King 
AuthorDate: Mon Apr 18 11:07:07 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 11:07:07 2016 -0400

Merge topic 'refactor-cmListFileBacktrace'

0f96ef00 Remove unused cmake::IssueMessage overload
563bf9dd cmState: Remove unused entry point fields from snapshot data
7c36d206 cmListFileBacktrace: Refactor storage to provide efficient value 
semantics
1f6bd8a9 cmState: Avoid accumulating snapshot storage for backtraces
18b6676b cmState: Add Snapshot method to get bottom of call stack


---

Summary of changes:
 Source/cmListFileCache.cxx |  176 
 Source/cmListFileCache.h   |   55 --
 Source/cmMakefile.cxx  |  140 +---
 Source/cmMakefile.h|2 +-
 Source/cmState.cxx |   60 ++-
 Source/cmState.h   |   20 +--
 Source/cmake.cxx   |   35 
 Source/cmake.h |3 -
 Tests/RunCMake/PolicyScope/NotClosed-stderr.txt|2 +-
 Tests/RunCMake/Syntax/FunctionUnmatched-stderr.txt |6 +-
 Tests/RunCMake/Syntax/MacroUnmatched-stderr.txt|6 +-
 .../TargetSources/OriginDebugIDE-stderr.txt|2 +-
 Tests/RunCMake/find_package/PolicyPush-stderr.txt  |2 +-
 Tests/RunCMake/while/EndMismatch-stderr.txt|2 +-
 Tests/RunCMake/while/EndMissing-stderr.txt |6 +-
 15 files changed, 269 insertions(+), 248 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-461-gef71350

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  ef713503c8b9b317fdbd21c75d332febd77c31a3 (commit)
   via  2faa8b362050c716cc5626f9bb9d8a8612b97f95 (commit)
   via  da07c506b9044e89ad9d904450aa590bb260bd78 (commit)
   via  cc7aed77a8774c565c8bc6c4965f10e3560f8d64 (commit)
   via  c50285dee66394b68eb3df17d190072289a33a4e (commit)
   via  b6ed71b17c888c5f79129871bf7bc865b43063e3 (commit)
   via  a559f0f6b020697a064517637ae04f0733ffc6ea (commit)
   via  7503deb2c55a32f72c9ec34f17a800d4ab1e4c75 (commit)
  from  0256ea55abe019b3a9b487e422b327722ed8935c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=ef713503c8b9b317fdbd21c75d332febd77c31a3
commit ef713503c8b9b317fdbd21c75d332febd77c31a3
Merge: 0256ea5 2faa8b3
Author: Brad King 
AuthorDate: Mon Apr 18 11:07:04 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 11:07:04 2016 -0400

Merge topic 'minor-cleanups'

2faa8b36 Add call stack to unused/uninitialized variable warnings
da07c506 cmLocalGenerator: Simplify IssueMessage implementation
cc7aed77 cmLocalGenerator: Use own IssueMessage method
c50285de cmOutputConverter: Assert construction with a valid snapshot
b6ed71b1 cmMakefile: Move cmMakefileCall to .cxx file
a559f0f6 cmWhileCommand: Simplify context construction
7503deb2 cmIfCommand: Simplify execution context construction


---

Summary of changes:
 Source/cmCommandArgumentParserHelper.cxx |9 +
 Source/cmIfCommand.cxx   |   10 ++
 Source/cmLocalGenerator.cxx  |   16 ++---
 Source/cmMakefile.cxx|   53 +-
 Source/cmMakefile.h  |   13 
 Source/cmOutputConverter.cxx |1 +
 Source/cmWhileCommand.cxx|8 ++---
 7 files changed, 32 insertions(+), 78 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[CMake] Patch for BundleUtilities to ignore specified files

2016-04-18 Thread Roman Wüger
Hello,

attached is a patch with which files can be specified which should not be 
resolved.

Best regards
Roman




0001-BundleUtilities-Add-optional-parameter-to-ignore-spe.patch
Description: Binary data

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[Cmake-commits] CMake branch, next, updated. v3.5.2-987-g8f84ab9

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  8f84ab9c4fe1d9b192d5795475c95988231dd3b1 (commit)
   via  db08bcc163150ac7f58fb66b1300b7236dea8d1b (commit)
  from  047a12918207a0ce32a71fcfb7fb14f4233ebddd (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8f84ab9c4fe1d9b192d5795475c95988231dd3b1
commit 8f84ab9c4fe1d9b192d5795475c95988231dd3b1
Merge: 047a129 db08bcc
Author: Brad King 
AuthorDate: Mon Apr 18 10:25:17 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 10:25:17 2016 -0400

Merge topic 'fix-addtest-and-crosscompiling-emulator-to-work-globally' into 
next

db08bcc1 Revert "TestGenerator: Extend crosscompiling emulator test case"


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=db08bcc163150ac7f58fb66b1300b7236dea8d1b
commit db08bcc163150ac7f58fb66b1300b7236dea8d1b
Author: Brad King 
AuthorDate: Mon Apr 18 10:25:03 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 10:25:03 2016 -0400

Revert "TestGenerator: Extend crosscompiling emulator test case"

This reverts commit 7df92ec78dc22692f89a12ad6feec4e193c7edaa.

diff --git a/Tests/RunCMake/CrosscompilingEmulator/AddTest-check.cmake 
b/Tests/RunCMake/CrosscompilingEmulator/AddTest-check.cmake
index 2dd6e85..0aae06c 100644
--- a/Tests/RunCMake/CrosscompilingEmulator/AddTest-check.cmake
+++ b/Tests/RunCMake/CrosscompilingEmulator/AddTest-check.cmake
@@ -4,13 +4,9 @@ if(EXISTS "${testfile}")
 else()
   message(FATAL_ERROR "Could not find expected CTestTestfile.cmake.")
 endif()
-set(error_details "There is a problem with generated test file: ${testfile}")
 if(testfile_contents MATCHES "add_test[(]DoesNotUseEmulator 
^(pseudo_emulator)+$")
-  message(SEND_ERROR "Used emulator when it should not be used. 
${error_details}")
+  message(SEND_ERROR "Used emulator when it should not be used.")
 endif()
 if(NOT testfile_contents MATCHES "add_test[(]UsesEmulator 
.+pseudo_emulator.+$")
-  message(SEND_ERROR "Did not use emulator when it should be used. 
${error_details}")
-endif()
-if(NOT testfile_contents MATCHES 
"add_test[(]UsesEmulatorWithExecTargetFromSubdirAddedWithoutGenex 
.+pseudo_emulator.+$")
-  message(SEND_ERROR "Did not use emulator when it should be used. 
${error_details}")
+  message(SEND_ERROR "Did not use emulator when it should be used.")
 endif()
diff --git a/Tests/RunCMake/CrosscompilingEmulator/AddTest.cmake 
b/Tests/RunCMake/CrosscompilingEmulator/AddTest.cmake
index b6eacf1..41850f2 100644
--- a/Tests/RunCMake/CrosscompilingEmulator/AddTest.cmake
+++ b/Tests/RunCMake/CrosscompilingEmulator/AddTest.cmake
@@ -6,8 +6,3 @@ add_test(NAME DoesNotUseEmulator
 add_executable(generated_exe simple_src.cxx)
 add_test(NAME UsesEmulator
   COMMAND generated_exe)
-
-add_subdirectory(AddTest)
-
-add_test(NAME UsesEmulatorWithExecTargetFromSubdirAddedWithoutGenex
-  COMMAND generated_exe_in_subdir_added_to_test_without_genex)
diff --git a/Tests/RunCMake/CrosscompilingEmulator/AddTest/CMakeLists.txt 
b/Tests/RunCMake/CrosscompilingEmulator/AddTest/CMakeLists.txt
deleted file mode 100644
index a10a694..000
--- a/Tests/RunCMake/CrosscompilingEmulator/AddTest/CMakeLists.txt
+++ /dev/null
@@ -1 +0,0 @@
-add_executable(generated_exe_in_subdir_added_to_test_without_genex 
${CMAKE_CURRENT_SOURCE_DIR}/../simple_src.cxx)

---

Summary of changes:
 Tests/RunCMake/CrosscompilingEmulator/AddTest-check.cmake|8 ++--
 Tests/RunCMake/CrosscompilingEmulator/AddTest.cmake  |5 -
 Tests/RunCMake/CrosscompilingEmulator/AddTest/CMakeLists.txt |1 -
 3 files changed, 2 insertions(+), 12 deletions(-)
 delete mode 100644 Tests/RunCMake/CrosscompilingEmulator/AddTest/CMakeLists.txt


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[cmake-developers] Patch for BundleUtilities to ignore specified files

2016-04-18 Thread Roman Wüger
Hello,

attached is a patch with which files can be specified which should not be 
resolved.

Best regards
Roman




0001-BundleUtilities-Add-optional-parameter-to-ignore-spe.patch
Description: Binary data

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers

[Cmake-commits] CMake branch, next, updated. v3.5.2-989-g5734a2f

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  5734a2f6d5e26ed8d07c46e95c5a62ac73ed6384 (commit)
   via  a6c98a177593356e500391c01751995f0de3fb2b (commit)
  from  8f84ab9c4fe1d9b192d5795475c95988231dd3b1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5734a2f6d5e26ed8d07c46e95c5a62ac73ed6384
commit 5734a2f6d5e26ed8d07c46e95c5a62ac73ed6384
Merge: 8f84ab9 a6c98a1
Author: Brad King 
AuthorDate: Mon Apr 18 10:26:54 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 10:26:54 2016 -0400

Merge topic 'teach-custom-command-crosscompiling-emulator' into next

a6c98a17 Revert topic 'teach-custom-command-crosscompiling-emulator'


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a6c98a177593356e500391c01751995f0de3fb2b
commit a6c98a177593356e500391c01751995f0de3fb2b
Author: Brad King 
AuthorDate: Mon Apr 18 10:26:32 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 10:26:32 2016 -0400

Revert topic 'teach-custom-command-crosscompiling-emulator'

It will be revised and restored later.

diff --git a/Help/command/add_custom_command.rst 
b/Help/command/add_custom_command.rst
index 021dcad..8726b70 100644
--- a/Help/command/add_custom_command.rst
+++ b/Help/command/add_custom_command.rst
@@ -78,9 +78,7 @@ The options are:
 
   If ``COMMAND`` specifies an executable target (created by the
   :command:`add_executable` command) it will automatically be replaced
-  by the location of the executable created at build time. If set, the
-  :variable:`CMAKE_CROSSCOMPILING_EMULATOR` variable will also be prepended
-  to the command to allow the executable to run on the host.
+  by the location of the executable created at build time.
   (Use the ``TARGET_FILE``
   :manual:`generator expression ` to
   reference an executable later in the command line.)
diff --git a/Help/command/add_custom_target.rst 
b/Help/command/add_custom_target.rst
index f67f55a..82d69db 100644
--- a/Help/command/add_custom_target.rst
+++ b/Help/command/add_custom_target.rst
@@ -60,9 +60,7 @@ The options are:
 
   If ``COMMAND`` specifies an executable target (created by the
   :command:`add_executable` command) it will automatically be replaced
-  by the location of the executable created at build time. If set, the
-  :variable:`CMAKE_CROSSCOMPILING_EMULATOR` variable will also be prepended
-  to the command to allow the executable to run on the host.
+  by the location of the executable created at build time.
   Additionally a target-level dependency will be added so that the
   executable target will be built before this custom target.
 
diff --git a/Help/prop_tgt/CROSSCOMPILING_EMULATOR.rst 
b/Help/prop_tgt/CROSSCOMPILING_EMULATOR.rst
index 626f339..3ef8e03 100644
--- a/Help/prop_tgt/CROSSCOMPILING_EMULATOR.rst
+++ b/Help/prop_tgt/CROSSCOMPILING_EMULATOR.rst
@@ -2,5 +2,5 @@ CROSSCOMPILING_EMULATOR
 ---
 
 Use the given emulator to run executables created when crosscompiling.  This
-command will be added as a prefix to :command:`add_test`, 
:command:`add_custom_command`
-and :command:`add_custom_target` commands for built target system executables.
+command will be added as a prefix to :command:`add_test` test commands for
+built target system executables.
diff --git a/Source/cmCustomCommandGenerator.cxx 
b/Source/cmCustomCommandGenerator.cxx
index 238fd66..dc06678 100644
--- a/Source/cmCustomCommandGenerator.cxx
+++ b/Source/cmCustomCommandGenerator.cxx
@@ -39,39 +39,6 @@ unsigned int cmCustomCommandGenerator::GetNumberOfCommands() 
const
 }
 
 //
-const char* LookupCrossCompilingEmulator(
-cmsys::auto_ptr cge)
-{
-  for(std::set::const_iterator ci =
-  cge->GetTargets().begin();
-  ci != cge->GetTargets().end(); ++ci)
-{
-cmGeneratorTarget* target = (*ci);
-const char* emulator = target->GetProperty("CROSSCOMPILING_EMULATOR");
-if (emulator != 0)
-  {
-  return emulator;
-  }
-}
-  return 0;
-}
-
-//
-bool cmCustomCommandGenerator::UseCrossCompilingEmulator(unsigned int c) const
-{
-  std::string const& argv0 = this->CC.GetCommandLines()[c][0];
-  cmGeneratorTarget* target =
-  this->LG->FindGeneratorTargetToUse(argv0);
-  if(target && target->GetType() == cmState::EXECUTABLE)
-{
-return 

Re: [CMake] CMakeLists.txt: How to print a message if ctest fails?

2016-04-18 Thread Matějů Miroslav , Ing .
Hi Muhammad,
you can use a CTest script, see https://cmake.org/Wiki/CMake_Scripting_Of_CTest 
for details. I use the following code in my CTest script:

if(configure_failed OR build_failed OR test_failed)
message(FATAL_ERROR "Test ${CTEST_BUILD_NAME} failed.")
endif()

Best regards,
Miroslav

From: CMake [mailto:cmake-boun...@cmake.org] On Behalf Of Muhammad Osama
Sent: Friday, April 15, 2016 8:53 PM
To: cmake@cmake.org
Subject: [CMake] CMakeLists.txt: How to print a message if ctest fails?

Is there a way I can setup CMakeLists.txt to print a message if ctest tests 
fail? For example:

cmake ..
make
ctest // fails
message output: Please contact x...@mail.com to resolve 
testing problems.
​Note the message output is not for cmake but for ctest.​

--​​
Muhammad
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[Cmake-commits] CMake branch, next, updated. v3.5.2-985-g047a129

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  047a12918207a0ce32a71fcfb7fb14f4233ebddd (commit)
   via  0f96ef00cbe8dd82cee32f61f9da43e66e42f446 (commit)
   via  563bf9dd8a207e04697a92d8bcd239f52400b355 (commit)
   via  7c36d2067b00996fcead56310f4fc4fa58434247 (commit)
  from  5755af3f986fe8553afc1bc56509906d54551c8e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=047a12918207a0ce32a71fcfb7fb14f4233ebddd
commit 047a12918207a0ce32a71fcfb7fb14f4233ebddd
Merge: 5755af3 0f96ef0
Author: Brad King 
AuthorDate: Mon Apr 18 09:21:32 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 09:21:32 2016 -0400

Merge topic 'refactor-cmListFileBacktrace' into next

0f96ef00 Remove unused cmake::IssueMessage overload
563bf9dd cmState: Remove unused entry point fields from snapshot data
7c36d206 cmListFileBacktrace: Refactor storage to provide efficient value 
semantics


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0f96ef00cbe8dd82cee32f61f9da43e66e42f446
commit 0f96ef00cbe8dd82cee32f61f9da43e66e42f446
Author: Brad King 
AuthorDate: Fri Apr 15 10:32:54 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 09:21:19 2016 -0400

Remove unused cmake::IssueMessage overload

All callers now pass a full backtrace so we do not need the alternative
that takes a cmListFileContext directly.  Drop this overload to remove
the code duplication.

diff --git a/Source/cmake.cxx b/Source/cmake.cxx
index dcc95af..8e3380f 100644
--- a/Source/cmake.cxx
+++ b/Source/cmake.cxx
@@ -2785,41 +2785,6 @@ void cmake::IssueMessage(cmake::MessageType t, 
std::string const& text,
 }
 
 //
-void cmake::IssueMessage(cmake::MessageType t, std::string const& text,
- cmListFileContext const& lfc,
- bool force)
-{
-  if (!force)
-{
-// override the message type, if needed, for warnings and errors
-cmake::MessageType override = this->ConvertMessageType(t);
-if (override != t)
-  {
-  t = override;
-  force = true;
-  }
-}
-
-  if (!force && !this->IsMessageTypeVisible(t))
-{
-return;
-}
-
-  std::ostringstream msg;
-  if (!this->PrintMessagePreamble(t, msg))
-{
-return;
-}
-
-  // Add the immediate context.
-  msg << (lfc.Line ? " at " : " in ") << lfc;
-
-  printMessageText(msg, text);
-
-  displayMessage(t, msg);
-}
-
-//
 std::vector cmake::GetDebugConfigs()
 {
   std::vector configs;
diff --git a/Source/cmake.h b/Source/cmake.h
index 8496705..8644dda 100644
--- a/Source/cmake.h
+++ b/Source/cmake.h
@@ -358,9 +358,6 @@ class cmake
   void IssueMessage(cmake::MessageType t, std::string const& text,
 cmListFileBacktrace const& backtrace = cmListFileBacktrace(),
 bool force = false);
-  void IssueMessage(cmake::MessageType t, std::string const& text,
-cmListFileContext const& lfc,
-bool force = false);
 
   ///! run the --build option
   int Build(const std::string& dir,

https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=563bf9dd8a207e04697a92d8bcd239f52400b355
commit 563bf9dd8a207e04697a92d8bcd239f52400b355
Author: Brad King 
AuthorDate: Fri Apr 15 11:05:33 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 09:21:19 2016 -0400

cmState: Remove unused entry point fields from snapshot data

This information is now kept in cmMakefile::Backtrace.

diff --git a/Source/cmState.cxx b/Source/cmState.cxx
index f4ca113..bafb09e 100644
--- a/Source/cmState.cxx
+++ b/Source/cmState.cxx
@@ -35,8 +35,6 @@ struct cmState::SnapshotDataType
   cmLinkedTree::iterator Vars;
   cmLinkedTree::iterator Root;
   cmLinkedTree::iterator Parent;
-  std::string EntryPointCommand;
-  long EntryPointLine;
   std::vector::size_type IncludeDirectoryPosition;
   std::vector::size_type CompileDefinitionsPosition;
   std::vector::size_type CompileOptionsPosition;
@@ -1116,16 +1114,6 @@ std::string cmState::Snapshot::GetExecutionListFile() 
const
   return *this->Position->ExecutionListFile;
 }
 
-std::string cmState::Snapshot::GetEntryPointCommand() const
-{
-  return this->Position->EntryPointCommand;
-}
-
-long cmState::Snapshot::GetEntryPointLine() const
-{
-  return this->Position->EntryPointLine;
-}
-
 bool cmState::Snapshot::IsValid() const
 {
   return 

[Cmake-commits] CMake branch, next, updated. v3.5.2-981-g5755af3

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  5755af3f986fe8553afc1bc56509906d54551c8e (commit)
   via  84fd5cf5a2d6b7bf1c74962bd686df91200d28a3 (commit)
  from  7555b597ce38fb223c1d6cf1821eeb3065be3846 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5755af3f986fe8553afc1bc56509906d54551c8e
commit 5755af3f986fe8553afc1bc56509906d54551c8e
Merge: 7555b59 84fd5cf
Author: Brad King 
AuthorDate: Mon Apr 18 09:10:30 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 09:10:30 2016 -0400

Merge topic 'fix-addtest-and-crosscompiling-emulator-to-work-globally' into 
next

84fd5cf5 Revert "TestGenerator: Fix CROSSCOMPILING_EMULATOR support."


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=84fd5cf5a2d6b7bf1c74962bd686df91200d28a3
commit 84fd5cf5a2d6b7bf1c74962bd686df91200d28a3
Author: Brad King 
AuthorDate: Mon Apr 18 09:10:07 2016 -0400
Commit: Brad King 
CommitDate: Mon Apr 18 09:10:07 2016 -0400

Revert "TestGenerator: Fix CROSSCOMPILING_EMULATOR support."

This reverts commit 78077d705000986decbd0282014c09b214461d45.

diff --git 
a/Help/release/dev/fix-CROSSCOMPILING_EMULATOR-TestGenerator-support.rst 
b/Help/release/dev/fix-CROSSCOMPILING_EMULATOR-TestGenerator-support.rst
deleted file mode 100644
index 5be2e27..000
--- a/Help/release/dev/fix-CROSSCOMPILING_EMULATOR-TestGenerator-support.rst
+++ /dev/null
@@ -1,6 +0,0 @@
-Fix CROSSCOMPILING_EMULATOR TestGenerator support
--
-
-If specified, emulator is now consistently added as a prefix
-to :command:`add_test` test commands for built target system
-executables. It works for tests added in a parent directory.
diff --git a/Source/cmTestGenerator.cxx b/Source/cmTestGenerator.cxx
index 152d48a..b411f15 100644
--- a/Source/cmTestGenerator.cxx
+++ b/Source/cmTestGenerator.cxx
@@ -83,8 +83,6 @@ void cmTestGenerator::GenerateScriptForConfig(std::ostream& 
os,
   // Get the test command line to be executed.
   std::vector const& command = this->Test->GetCommand();
 
-  const char * emulator = 0;
-
   // Check whether the command executable is a target whose name is to
   // be translated.
   std::string exe = command[0];
@@ -95,45 +93,30 @@ void cmTestGenerator::GenerateScriptForConfig(std::ostream& 
os,
 // Use the target file on disk.
 exe = target->GetFullPath(config);
 
-// Lookup emulator
-emulator = target->GetProperty("CROSSCOMPILING_EMULATOR");
-}
-  else
-{
-// Use the command name given.
-cmsys::auto_ptr cge = ge.Parse(exe.c_str());
-exe = cge->Evaluate(this->LG, config);
-cmSystemTools::ConvertToUnixSlashes(exe);
-
-// Lookup emulator
-for(std::set::const_iterator ci =
-cge->GetTargets().begin();
-ci != cge->GetTargets().end(); ++ci)
+// Prepend with the emulator when cross compiling if required.
+const char * emulator =
+  target->GetProperty("CROSSCOMPILING_EMULATOR");
+if (emulator != 0)
   {
-  target = (*ci);
-  emulator = target->GetProperty("CROSSCOMPILING_EMULATOR");
-  if (emulator != 0)
+  std::vector emulatorWithArgs;
+  cmSystemTools::ExpandListArgument(emulator, emulatorWithArgs);
+  std::string emulatorExe(emulatorWithArgs[0]);
+  cmSystemTools::ConvertToUnixSlashes(emulatorExe);
+  os << cmOutputConverter::EscapeForCMake(emulatorExe) << " ";
+  for(std::vector::const_iterator ei =
+  emulatorWithArgs.begin()+1;
+  ei != emulatorWithArgs.end();
+  ++ei)
 {
-break;
+os << cmOutputConverter::EscapeForCMake(*ei) << " ";
 }
   }
 }
-
-  // Prepend with the emulator when cross compiling if required.
-  if (emulator != 0)
+  else
 {
-std::vector emulatorWithArgs;
-cmSystemTools::ExpandListArgument(emulator, emulatorWithArgs);
-std::string emulatorExe(emulatorWithArgs[0]);
-cmSystemTools::ConvertToUnixSlashes(emulatorExe);
-os << cmOutputConverter::EscapeForCMake(emulatorExe) << " ";
-for(std::vector::const_iterator ei =
-emulatorWithArgs.begin()+1;
-ei != emulatorWithArgs.end();
-++ei)
-  {
-  os << cmOutputConverter::EscapeForCMake(*ei) << " ";
-  }
+// Use the command name given.
+exe = ge.Parse(exe.c_str())->Evaluate(this->LG, config);
+cmSystemTools::ConvertToUnixSlashes(exe);
 }
 
   // Generate the command line with full escapes.
diff --git 

[Cmake-commits] CMake branch, master, updated. v3.5.2-451-gde3c7bd

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  de3c7bd7994490a01fc0805fcfff277f07cb9116 (commit)
   via  7b3a1069bf9e0ba5fd11231d00b99e8952b187a6 (commit)
  from  f5c8a46808dcf55652fe6bb13fca70bd241d5d46 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=de3c7bd7994490a01fc0805fcfff277f07cb9116
commit de3c7bd7994490a01fc0805fcfff277f07cb9116
Merge: f5c8a46 7b3a106
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:32 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:32 2016 -0400

Merge topic 'AddDocumentationForEclipseVariables'

7b3a1069 Help: Document Eclipse-generator related variables (#15827)


---

Summary of changes:
 Help/manual/cmake-variables.7.rst |4 
 Help/variable/CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES.rst |   10 ++
 Help/variable/CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT.rst   |   11 +++
 Help/variable/CMAKE_ECLIPSE_MAKE_ARGUMENTS.rst|9 +
 Help/variable/CMAKE_ECLIPSE_VERSION.rst   |   10 ++
 5 files changed, 44 insertions(+)
 create mode 100644 Help/variable/CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES.rst
 create mode 100644 Help/variable/CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT.rst
 create mode 100644 Help/variable/CMAKE_ECLIPSE_MAKE_ARGUMENTS.rst
 create mode 100644 Help/variable/CMAKE_ECLIPSE_VERSION.rst


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-453-g0256ea5

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  0256ea55abe019b3a9b487e422b327722ed8935c (commit)
   via  cc684857c2959d7a49c0c390dcf3361804648c0b (commit)
  from  de3c7bd7994490a01fc0805fcfff277f07cb9116 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0256ea55abe019b3a9b487e422b327722ed8935c
commit 0256ea55abe019b3a9b487e422b327722ed8935c
Merge: de3c7bd cc68485
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:37 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:37 2016 -0400

Merge topic 'cmPolicies-missing-include'

cc684857 cmPolicies.cxx: Add missing include  for isdigit (#16066)


---

Summary of changes:
 Source/cmPolicies.cxx |1 +
 1 file changed, 1 insertion(+)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-442-g942e9d5

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  942e9d5019853ea3274e883f2389d80f7f0dbc66 (commit)
   via  19e8752b86a015832b3414f55a298bda9896fc62 (commit)
  from  49c4d665dcb75fe92c8923fdd1fb13e7131d4391 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=942e9d5019853ea3274e883f2389d80f7f0dbc66
commit 942e9d5019853ea3274e883f2389d80f7f0dbc66
Merge: 49c4d66 19e8752
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:23 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:23 2016 -0400

Merge topic 'FindGit-update-github-location'

19e8752b FindGit: Add new 'GitHub for Windows' user directory


---

Summary of changes:
 Modules/FindGit.cmake |6 --
 1 file changed, 4 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-445-g21fb50d

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  21fb50d5121763fb4c34a831665f7740154c0891 (commit)
   via  2a99fae1cc30938a50fd55afd50c13b5c881c737 (commit)
   via  c4417b0927991130d1c701f844e7e2b3464a207e (commit)
  from  942e9d5019853ea3274e883f2389d80f7f0dbc66 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=21fb50d5121763fb4c34a831665f7740154c0891
commit 21fb50d5121763fb4c34a831665f7740154c0891
Merge: 942e9d5 2a99fae
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:25 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:25 2016 -0400

Merge topic 'FindMPI-intel-compiler'

2a99fae1 FindMPI: Recognize `.lib` file names for specification of link 
libraries
c4417b09 FindMPI: Recognize /LIBPATH for specification of linker paths.


---

Summary of changes:
 Modules/FindMPI.cmake |   15 +--
 1 file changed, 13 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.5.2-971-g26fbb4c

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  26fbb4c14e24ec9af40f2d2814b715017de14bd2 (commit)
   via  7b3a1069bf9e0ba5fd11231d00b99e8952b187a6 (commit)
  from  69b7868da554b594849d5c3d89839ee54d659cd8 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=26fbb4c14e24ec9af40f2d2814b715017de14bd2
commit 26fbb4c14e24ec9af40f2d2814b715017de14bd2
Merge: 69b7868 7b3a106
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:07 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:07 2016 -0400

Merge topic 'AddDocumentationForEclipseVariables' into next

7b3a1069 Help: Document Eclipse-generator related variables (#15827)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7b3a1069bf9e0ba5fd11231d00b99e8952b187a6
commit 7b3a1069bf9e0ba5fd11231d00b99e8952b187a6
Author: Alex Neundorf 
AuthorDate: Sun Apr 17 21:38:45 2016 +0200
Commit: Brad King 
CommitDate: Mon Apr 18 08:56:19 2016 -0400

Help: Document Eclipse-generator related variables (#15827)

diff --git a/Help/manual/cmake-variables.7.rst 
b/Help/manual/cmake-variables.7.rst
index 7cf3a3d..3e04763 100644
--- a/Help/manual/cmake-variables.7.rst
+++ b/Help/manual/cmake-variables.7.rst
@@ -116,6 +116,10 @@ Variables that Change Behavior
/variable/CMAKE_DEBUG_TARGET_PROPERTIES
/variable/CMAKE_DEPENDS_IN_PROJECT_ONLY
/variable/CMAKE_DISABLE_FIND_PACKAGE_PackageName
+   /variable/CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES
+   /variable/CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT
+   /variable/CMAKE_ECLIPSE_MAKE_ARGUMENTS
+   /variable/CMAKE_ECLIPSE_VERSION
/variable/CMAKE_ERROR_DEPRECATED
/variable/CMAKE_ERROR_ON_ABSOLUTE_INSTALL_DESTINATION
/variable/CMAKE_EXPORT_COMPILE_COMMANDS
diff --git a/Help/variable/CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES.rst 
b/Help/variable/CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES.rst
new file mode 100644
index 000..331aae8
--- /dev/null
+++ b/Help/variable/CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES.rst
@@ -0,0 +1,10 @@
+CMAKE_ECLIPSE_GENERATE_LINKED_RESOURCES
+---
+
+This cache variable is used by the Eclipse project generator.  See
+:manual:`cmake-generators(7)`.
+
+The Eclipse project generator generates so-called linked resources
+e.g. to the subproject root dirs in the source tree or to the source files
+of targets.
+This can be disabled by setting this variable to FALSE.
diff --git a/Help/variable/CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT.rst 
b/Help/variable/CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT.rst
new file mode 100644
index 000..7b4367d
--- /dev/null
+++ b/Help/variable/CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT.rst
@@ -0,0 +1,11 @@
+CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT
+-
+
+This cache variable is used by the Eclipse project generator.  See
+:manual:`cmake-generators(7)`.
+
+If this variable is set to TRUE, the Eclipse project generator will generate
+an Eclipse project in :variable:`CMAKE_SOURCE_DIR` . This project can then
+be used in Eclipse e.g. for the version control functionality.
+:variable:`CMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT` defaults to FALSE; so
+nothing is written into the source directory.
diff --git a/Help/variable/CMAKE_ECLIPSE_MAKE_ARGUMENTS.rst 
b/Help/variable/CMAKE_ECLIPSE_MAKE_ARGUMENTS.rst
new file mode 100644
index 000..6e8a408
--- /dev/null
+++ b/Help/variable/CMAKE_ECLIPSE_MAKE_ARGUMENTS.rst
@@ -0,0 +1,9 @@
+CMAKE_ECLIPSE_MAKE_ARGUMENTS
+
+
+This cache variable is used by the Eclipse project generator.  See
+:manual:`cmake-generators(7)`.
+
+This variable holds arguments which are used when Eclipse invokes the make
+tool. By default it is initialized to hold flags to enable parallel builds
+(using -j typically).
diff --git a/Help/variable/CMAKE_ECLIPSE_VERSION.rst 
b/Help/variable/CMAKE_ECLIPSE_VERSION.rst
new file mode 100644
index 000..8cc7882
--- /dev/null
+++ b/Help/variable/CMAKE_ECLIPSE_VERSION.rst
@@ -0,0 +1,10 @@
+CMAKE_ECLIPSE_VERSION
+-
+
+This cache variable is used by the Eclipse project generator.  See
+:manual:`cmake-generators(7)`.
+
+When using the Eclipse project generator, CMake tries to find the Eclipse
+executable and detect the version of it. Depending on the version it finds,
+some features are enabled or disabled. If CMake doesn't find
+Eclipse, it assumes the oldest supported version, Eclipse Callisto (3.2).

---

Summary of changes:



[Cmake-commits] CMake branch, master, updated. v3.5.2-449-gf5c8a46

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  f5c8a46808dcf55652fe6bb13fca70bd241d5d46 (commit)
   via  5dc6cfd6ea304c6eb49e7f4555d6d9778854929b (commit)
  from  0f6a8f7a46f91be249199b356f0cb9b2b508f6b0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f5c8a46808dcf55652fe6bb13fca70bd241d5d46
commit f5c8a46808dcf55652fe6bb13fca70bd241d5d46
Merge: 0f6a8f7 5dc6cfd
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:29 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:29 2016 -0400

Merge topic 'cmake-host-solaris'

5dc6cfd6 Solaris: Add a CMAKE_HOST_SOLARIS variable (#16061)


---

Summary of changes:
 Help/manual/cmake-variables.7.rst   |1 +
 Help/release/dev/cmake-host-solaris.rst |5 +
 Help/variable/CMAKE_HOST_SOLARIS.rst|6 ++
 Source/cmState.cxx  |3 +++
 4 files changed, 15 insertions(+)
 create mode 100644 Help/release/dev/cmake-host-solaris.rst
 create mode 100644 Help/variable/CMAKE_HOST_SOLARIS.rst


hooks/post-receive
diff --git a/Modules/WriteCompilerDetectionHeader.cmake 
b/Modules/WriteCompilerDetectionHeader.cmake
index a3b73bb..2669a84 100644
--- a/Modules/WriteCompilerDetectionHeader.cmake
+++ b/Modules/WriteCompilerDetectionHeader.cmake
@@ -36,7 +36,7 @@
 #  PREFIX ClimbingStats
 #  OUTPUT_FILES_VAR support_files
 #  OUTPUT_DIR compilers
 #  COMPILERS GNU Clang MSVC
 #  FEATURES cxx_variadic_templates
 #)
 #install(FILES
@@ -100,7 +100,7 @@
 #write_compiler_detection_header(
 #  FILE climbingstats_compiler_detection.h
 #  PREFIX ClimbingStats
 #  COMPILERS GNU Clang AppleClang MSVC
 #  FEATURES cxx_variadic_templates
 #)
 #
@@ -323,6 +323,7 @@ function(write_compiler_detection_header
 AppleClang
 MSVC
 SunPro
+Intel
   )
 
   set(_hex_compilers ADSP Borland Embarcadero SunPro)
@@ -36,7 +36,7 @@
 #  OUTPUT_FILES_VAR support_files
 #  OUTPUT_DIR compilers
-#  COMPILERS GNU Clang MSVC
+#  COMPILERS GNU Clang MSVC Intel
 #  FEATURES cxx_variadic_templates
 #)
@@ -100,7 +100,7 @@
 #  FILE climbingstats_compiler_detection.h
 #  PREFIX ClimbingStats
-#  COMPILERS GNU Clang AppleClang MSVC
+#  COMPILERS GNU Clang AppleClang MSVC Intel
 #  FEATURES cxx_variadic_templates
 #)
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-447-g0f6a8f7

2016-04-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  0f6a8f7a46f91be249199b356f0cb9b2b508f6b0 (commit)
   via  32d569af9a7174f53cd2abd0248385bfb7fc1929 (commit)
  from  21fb50d5121763fb4c34a831665f7740154c0891 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0f6a8f7a46f91be249199b356f0cb9b2b508f6b0
commit 0f6a8f7a46f91be249199b356f0cb9b2b508f6b0
Merge: 21fb50d 32d569a
Author: Brad King 
AuthorDate: Mon Apr 18 08:57:27 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Mon Apr 18 08:57:27 2016 -0400

Merge topic 'cmake-gui-osx-install-mkdir'

32d569af cmake-gui: Teach --install make destination directory (#16064)


---

Summary of changes:
 Source/QtDialog/CMakeSetup.cxx |1 +
 1 file changed, 1 insertion(+)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[CMake] Building output of add_custom_command in multiple targets in Visual Studio

2016-04-18 Thread Fujii Hironori
I have a problem building output of add_custom_command in multiple
projects causes unnecessary rebuild in Visual Studio.  This problem is
mentioned in the CMake documentation:

 add_custom_command — CMake 3.5.1 Documentation
 https://cmake.org/cmake/help/v3.5/command/add_custom_command.html

| Do not list the output in more than one independent target that may
| build in parallel or the two instances of the rule may conflict
| (instead use the add_custom_target() command to drive the command and
| make the other targets depend on that one).

But, the solution of using add_custom_target does not solve the problem.
This is a simplified CMake script:

| cmake_minimum_required(VERSION 3.5)
|
| project(hello VERSION 0.1 LANGUAGES CXX)
|
| add_custom_command(OUTPUT generated.cpp
|   COMMAND ${CMAKE_COMMAND} -E echo "int x;" >
${CMAKE_CURRENT_BINARY_DIR}/generated.cpp)
|
| add_executable(program_a
|   main_a.cxx
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
| )
|
| add_executable(program_b
|   main_b.cxx
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
| )
| add_dependencies(program_b program_a)

First time building ALL_BUILD, Visual Studio generates the
generated.cpp in both projects program_a and program_b.
Then, in the next time of ALL_BUILD, program_a is built because
generated.cpp is updated after building program_a.

Using add_custom_target does not solve the problem:

| cmake_minimum_required(VERSION 3.5)
|
| project(hello VERSION 0.1 LANGUAGES CXX)
|
| add_custom_command(OUTPUT generated.cpp
|   COMMAND ${CMAKE_COMMAND} -E echo "int x;" >
${CMAKE_CURRENT_BINARY_DIR}/generated.cpp)
|
| add_custom_target(generate DEPENDS ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp)
|
| set_source_files_properties(
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
|   PROPERTIES GENERATED 1)
|
| add_executable(program_a
|   main_a.cxx
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
| )
| add_dependencies(program_a generate)
|
| add_executable(program_b
|   main_b.cxx
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
| )
| add_dependencies(program_b program_a)
| add_dependencies(program_b generate)

In this case, the generated.cpp is generated in three project
generate, program_a and program_b.
program_a is built twice unnecessarily.

Another example of using add_custom_target:

| cmake_minimum_required(VERSION 3.5)
|
| project(hello VERSION 0.1 LANGUAGES CXX)
|
| add_custom_target(generate
| COMMAND ${CMAKE_COMMAND} -E echo "int x;" >
${CMAKE_CURRENT_BINARY_DIR}/generated.cpp)
|
| set_source_files_properties(
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
|   PROPERTIES GENERATED 1)
|
| add_executable(program_a
|   main_a.cxx
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.add
| )
| cpp_dependencies(program_a generate)
|
| add_executable(program_b
|   main_b.cxx
|   ${CMAKE_CURRENT_BINARY_DIR}/generated.cpp
| )
| add_dependencies(program_b generate)
| add_dependencies(program_b program_a)

In this case, the generated.cpp is generated every time.

Is there a way to specify not to invoke the custom command in
program_a and program_b?
I'm using Visual Studio 2015.
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake